# echo-cli

[![npm](https://img.shields.io/npm/v/echo-cli.svg?maxAge=2592000&style=flat-square&reset-cache-2)](https://www.npmjs.com/package/echo-cli) [![Travis](https://img.shields.io/travis/iamakulov/echo-cli.svg?maxAge=2592000&style=flat-square&reset-cache-2)](https://travis-ci.org/iamakulov/echo-cli) [![Coveralls](https://img.shields.io/coveralls/iamakulov/echo-cli.svg?maxAge=2592000&style=flat-square&reset-cache-2)](https://coveralls.io/github/iamakulov/echo-cli)

> A cross-platform CLI for outputting text to the command line (with escape sequences)

Why? Because Windows’ CMD doesn’t support escape sequences, and even [a new line is printed differently from Bash](http://stackoverflow.com/a/132804/1192426). This makes outputting something from npm scripts much more challenging.

## Install

To use in your package:

```
npm install --save-dev echo-cli
```

To use from the command line:

```
npm install --global echo-cli
```

## Usage

`echo-cli` supports all JavaScript escape sequences described [on the according MDN page](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Grammar_and_types#Using_special_characters_in_strings). Feel free to open an issue if you need the Bash escape sequences too.

When passing an escape sequence, wrap the passed text into quotes to prevent Bash from interpreting the sequence on its own.

```js
// In package.json
{
    "scripts": {
        "build": "echo-cli Building the project... && babel src -d dist",
        "test": "echo-cli 'Running the tests...\\nThis usually takes a couple of minutes.' && ava",
    }
}

// Or in Webpack config
{
    plugins: [
        new WebpackShellPlugin({
            onBuildEnd: ['copyfiles dist ../archive/dist && echo-cli "\\nCopied the build results"']
        })
    ]
}
```

## License

MIT © [Ivan Akulov](http://iamakulov.com)